@@ -44,9 +44,14 @@ func (e *Executor) compiledTask(call *Call, evaluateShVars bool) (*ast.Task, err
 	if err != nil {
 		return nil, err
 	}
+	fullName := origTask.Task
+	if matches, exists := vars.Get("MATCH"); exists {
+		for _, match := range matches.Value.([]string) {
+			fullName = strings.Replace(fullName, "*", match, 1)
+		}
+	}
 
 	cache := &templater.Cache{Vars: vars}
-
 	new := ast.Task{
 		Task:                 origTask.Task,
 		Label:                templater.Replace(origTask.Label, cache),
@@ -76,6 +81,7 @@ func (e *Executor) compiledTask(call *Call, evaluateShVars bool) (*ast.Task, err
 		Requires:             origTask.Requires,
 		Watch:                origTask.Watch,
 		Namespace:            origTask.Namespace,
+		FullName:             fullName,
 	}
 	new.Dir, err = execext.ExpandLiteral(new.Dir)
 	if err != nil {
